pyqode.python.managers package
==============================

Module contents
---------------

.. automodule:: pyqode.python.managers

Classes
-------

PyFileManager
+++++++++++++

.. autoclass:: pyqode.python.managers.PyFileManager
    :members:
    :undoc-members:
    :show-inheritance:
